# eric7.Plugins.VcsPlugins.vcsMercurial.HgExtension

Module implementing the base class for Mercurial extension interfaces.

### Global Attributes

None

### Classes

HgExtension | Class implementing the base class for Mercurial extension interfaces.

### Functions

None

## HgExtension

Class implementing the base class for Mercurial extension interfaces.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

HgExtension | Constructor
shutdown | Public method used to shutdown the extension interface.

### Static Methods

None

#### HgExtension (Constructor)

HgExtension(vcs)

Constructor

vcs
  reference to the Mercurial vcs object

#### HgExtension.shutdown

shutdown()

Public method used to shutdown the extension interface.

The method of this base class does nothing.

Up